# SODETLIB

This repository contains tools for controlling the Simons Observatory readout
system, and performing initial data analysis for detector characterization.

## Installation

Instructions for setting up a SMuRF server can be found on the
[SO Wiki].

For offline analysis of sodetlib data files, you can also install sodetlib
by cloning this repo and running:

```
pip3 install .
```

[SO Wiki]: http://simonsobservatory.wikidot.com/smurf-software-setup

## Documentation

Sodetlib documentation is hosted on [ReadTheDocs].

[ReadTheDocs]: https://sodetlib.readthedocs.io/en/latest/

## Contributing

Contributions to SODETLIB are very welcome!
Pull requests must be approved by one member of the simonsobs team before being
merged.

## Licence

This project is licensed under the BSD 2-Clause License - see the [LICENSE]
file for details.

[LICENSE]: LICENSE
